/*
 * III Mistrzostwa Wielkopolski w Programowaniu Zespolowym
 * Poznan, 2-3.XII.2005
 *
 * Rozwiazanie wzorcowe do zadania A - Miasta i drogi
 * Zlozonosc: O(N)
 *
 * Autor programu: Bartosz Nowierski
 */

#include <stdio.h>

#define NDEBUG
#include <assert.h>
/* assert'y sa tylko i wylacznie w celu dodatkowego sprawdzenia wejscia
   i wynikow posrednich; nie sa wkompilowane w ostatecznej wersji
   (poprzez odkomentowanie powyzszej definicji NDEBUG) */


#define MAXD 50

#define MINN 2
#define MAXN 100000
#define MAXDEG 100000


#define min(a, b) (((a) < (b)) ? (a) : (b))


int N; /* liczba miast */
int A[MAXN]; /* stopnie miast (liczba tras wylotowych) */
int D[MAXN]; /* ciag roznic miedzy kolejnymi miastami, uefektywnia sledzenie zmian */

struct GROUP /* przez "grupke" rozumiemy serie miast kolo siebie o tym samym stopniu */
{
  int beg, end; /* poczatek i koniec grupki */
  int prev, next; /* "wskazniki" na poprzednia i nastepna grupke */
  int diffprev, diffnext; /* roznica stopni pomiedzy ta oraz nastepna i poprzednia grupka */
} groups[2*MAXN];
int grcnt;



void sortngroup()
/* sortuje miasta poprzez zliczanie w czasie O(N) i wypelnia inne wazne struktury */
{
  int S[MAXN];
  int prevdeg;
  int i, k;
#ifndef NDEBUG
  int checksum, sum;

  checksum = 0;
  sum = 0;
  for (i = 0; i < N; ++i)
  {
    checksum += A[i];
  }
#endif
  
  for (i = 0; i <= min(N-1, MAXDEG); ++i)
  {
    S[i] = 0;
  }
  for (i = 0; i < N; ++i)
  {
    assert(A[i] < N); /* gdy >=N odpowiedz jest NIE, i to juz powinno byc wczesniej sprawdzone */
    ++S[A[i]];
  }

  grcnt = 0;
  prevdeg = -1;
  k = 0;
  for (i = min(N-1, MAXDEG); i >= 0; --i)
  {
    if (S[i] > 0)
    {
      assert(grcnt < N);
      groups[grcnt].beg = k;
      groups[grcnt].end = k+S[i]-1;
      groups[grcnt].next = -1;
      if (grcnt > 0)
      {
        groups[grcnt].prev = grcnt-1;
        assert((prevdeg >= 0) && (prevdeg > i));
        groups[grcnt-1].next = grcnt;
        groups[grcnt].diffprev = prevdeg-i;
        groups[grcnt-1].diffnext = prevdeg-i;
        assert(groups[grcnt-1].end+1 == groups[grcnt].beg);
      }
      else
      {
        groups[grcnt].prev = -1;
      }
      prevdeg = i;
      ++grcnt;
    }

    while (S[i] > 0)
    {
      A[k] = i;
      ++k;
      --S[i];
      assert(k <= N);
    }
    assert(((0 == grcnt) && (0 == k)) || (k-1 == groups[grcnt-1].end));
  }
  assert(k == N);

#ifndef NDEBUG
  sum = A[0];
#endif
  /* wypelnij ciag roznic (i zweryfikuj posortowanie) */
  for (i = 1; i < N; ++i)
  {
    assert(A[i-1] >= A[i]); /* sprawdz czy tablica posortowana */
    D[i-1] = A[i]-A[i-1];
#ifndef NDEBUG
    sum += A[i];
#endif
  }
  /* trudno sprawdzic czy odtworzylismy wszystkie elementy, wiec przynajmniej zweryfikujmy sume */
  assert(sum == checksum);
}



int main()
{
  int d;
  int i;
  int impossible;
  int degree;
  int group, nextgroup, prevgroup, newgroup, beggroup;
  int size;
  int scanres;
  
  
  /* wczyraj liczbe testow */
  scanres = scanf("%d", &d);
  assert(1 == scanres);
  assert((d > 0) && (d <= MAXD));

  while (d--)
  {
    /* wczytj dane */
    scanres = scanf("%d", &N);
    assert(1 == scanres);
    assert((N >= MINN) && (N <= MAXN));

    impossible = 0;
    for (i = 0; i < N; i++)
    {
      scanres = scanf("%d", &A[i]);
      assert(1 == scanres);
      assert((A[i] >= 0) && (A[i] <= MAXDEG));
      if (A[i] >= N)
      {
        impossible = 1;
      }
      D[i] = 0;
    }
    if (impossible)
    {
      goto IMPOSSIBLE;
    }

    /* posortuj stopnie miast i wypelnij tablice grupek oraz ciag roznic */
    sortngroup();

    degree = A[0];
    group = 0;
    beggroup = 0;
    assert(degree >= 0);
    for (i = 0; i < N; i++)
    {
      if ((degree < 0) || (N-i-1 < degree))
      {
        goto IMPOSSIBLE;
      }
      if (0 == degree)
      {
        degree += D[i];
        continue;
      }
        
 
      while (groups[beggroup].end < i+1)
      {
        beggroup = groups[beggroup].next;
        groups[beggroup].prev = -1;
        assert(groups[beggroup].end >= i+1); /* powinno to sie skonczyc na 1 petli */
      }
      groups[beggroup].beg = i+1;
      
      /* zachlannie polacz aktualne miasto z miastami o najwiekszych stopniach;
         moze sie jednak okazac, ze musimy podzielic jedna grupke na osobne kawalki
         lub musimy poscalac niektore grupki */
      
      /* najpierw znajdz grupke, w ktorej konczysie zmniejszany przedzial */
      while (i+degree > groups[group].end)
      {
        group = groups[group].next;
        assert(group >= 0);
        assert((0 == i) || (i+degree <= groups[group].end)); /* tylko w pierwszej rundzie
          mozna przejsc wiecej grupek, pozniej tylko 1 */
      }
      while (i+degree < groups[group].beg)
      {
        group = groups[group].prev;
        assert(group >= 0);
      }
      assert((i+degree >= groups[group].beg) && (i+degree <= groups[group].end));

      newgroup = group;
      if (i+degree < groups[group].end)
      {
        /* przedzial miast ktore chcemy zmniejszyc spowoduje rozdzielnie
           jednej grupki na 2 czesci; bedziemy musieli zmniejszyc koncowke tej
           przedzialu, a nie jej poczatek */
        
        size = i+degree-groups[group].beg+1; /* liczba miast do zmniejszenia w feralnej grupce */
        /* pozmniejszaj stopnie */
        --D[i];
        ++D[i+degree-size];
        --D[groups[group].end-size];
        ++D[groups[group].end];

        /* nastepnie rozdziel feralna grupke i poscalaj z sasiednimi jesli trzeba */
         
        nextgroup = groups[group].next;
        prevgroup = groups[group].prev;

        if (nextgroup >= 0)
        {
          assert(groups[group].end+1 == groups[nextgroup].beg);
          assert((groups[group].diffnext == groups[nextgroup].diffprev) && (groups[group].diffnext > 0));
          if (1 == groups[group].diffnext)
          {
            groups[nextgroup].beg -= size;
            groups[group].end -= size;
            newgroup = nextgroup;
          }
          else
          {
            assert(grcnt < 2*MAXN);
            groups[grcnt].end = groups[group].end;
            groups[group].end -= size;
            groups[grcnt].beg = groups[group].end+1;
            groups[grcnt].prev = group;
            groups[grcnt].next = nextgroup;
            groups[grcnt].diffnext = groups[group].diffnext-1;
            groups[nextgroup].prev = grcnt;
            groups[nextgroup].diffprev = groups[grcnt].diffnext;
            groups[grcnt].diffprev = 1;
            groups[group].next = grcnt;
            groups[group].diffnext = 1;
            newgroup = grcnt;
            ++grcnt;
          }
        }
        else
        {
          assert(grcnt < 2*MAXN);
          groups[grcnt].end = groups[group].end;
          groups[group].end -= size;
          groups[grcnt].beg = groups[group].end+1;
          groups[grcnt].prev = group;
          groups[grcnt].next = -1;
          groups[grcnt].diffprev = 1;
          groups[group].next = grcnt;
          groups[group].diffnext = 1;
          newgroup = grcnt;
          ++grcnt;
        }

        if (prevgroup >= 0)
        {
          assert(groups[prevgroup].end+1 == groups[group].beg);
          assert((groups[prevgroup].diffnext == groups[group].diffprev) && (groups[group].diffprev > 0));

          if (1 == groups[group].diffprev)
          {
            groups[prevgroup].end = groups[group].end;
            groups[prevgroup].next = groups[group].next;
            groups[prevgroup].diffnext = groups[group].diffnext;
            nextgroup = groups[group].next;
            if (nextgroup >= 0)
            {
              groups[nextgroup].prev = prevgroup;
              assert(groups[nextgroup].diffprev == groups[prevgroup].diffnext);
            }
            else
            {
              assert(0); /* ten przypadek nie powinine sie zdarzyc, bo powyzej 
                tworzymy nowa grupke jesli nie istnieje */
              newgroup = prevgroup;
            }
            assert(newgroup != group);
          }
          else
          {
            --groups[group].diffprev;
            --groups[prevgroup].diffnext;
          }
        }
        else
        {
          /* nic nie rob */
        }
      }
      else
      {
        /* wszystkie grupki majace czesc wspolna ze zmniejszanym przedzialem sie w nim zawieraja */
        --D[i];
        ++D[i+degree];
        
        nextgroup = groups[group].next;
        if (nextgroup >= 0)
        {
          assert(groups[group].end+1 == groups[nextgroup].beg);
          assert((groups[group].diffnext == groups[nextgroup].diffprev) && (groups[group].diffnext > 0));
          if (1 == groups[group].diffnext)
          {
            groups[nextgroup].beg = groups[group].beg;
            groups[nextgroup].prev = groups[group].prev;
            groups[nextgroup].diffprev = groups[group].diffprev;
            prevgroup = groups[group].prev;
            if (prevgroup >= 0)
            {
              groups[prevgroup].next = nextgroup;
              assert(groups[prevgroup].diffnext == groups[group].diffprev);
            }
            else
            {
              beggroup = nextgroup;
            }
            newgroup = nextgroup;
          }
          else
          {
            --groups[group].diffnext;
            --groups[nextgroup].diffprev;
          }
        }
        else
        {
          /* nic nie rob */
        }
      }
      group = newgroup;
      degree += D[i];
    }

    printf("TAK\n");
    continue;
IMPOSSIBLE:
    printf("NIE\n");
  }
  
  return 0;
}

