/*
 * III Mistrzostwa Wielkopolski w Programowaniu Zespolowym
 * Poznan, 2-3.XII.2005
 *
 * Rozwiazanie wzorcowe do zadania J - Telefony
 * Zlozonosc: O(M*L+N*2^L)
 *
 * Autor programu: Bartosz Nowierski
 */

#include <stdio.h>
#include <string.h>

//#define NDEBUG  
#include <assert.h>
/* assert'y sa tylko i wylacznie w celu dodatkowego sprawdzenia wejscia
   i wynikow posrednich; nie sa wkompilowane w ostatecznej wersji
   (poprzez odkomentowanie powyzszej definicji NDEBUG) */


#define MAXD 50

#define MAXM 10000
#define MAXL 9
#define MAXN 500



struct NODE /* wezel w drzewie slownikowym (przechowuje slowa skonwertowane na cryfry) */
{
  int child[10];  /* "wskazniki" na kolejne wezly */
  int cnt;  /* liczba slow ktore koncza sie w tym wezle */
} tree[MAXM*MAXL+1];
int treesize;

int N, M, L;
int number[MAXL+1];



int char2dig(char ch)
/* skonwertuje litere na cyfre */
{
  assert((ch >= 'a') && (ch <= 'z'));
  assert(('x' != ch) && ('q' != ch) && ('v' != ch));
  if (ch <= 'b') return 1;
  if (ch <= 'd') return 2;
  if (ch <= 'g') return 3;
  if (ch <= 'j') return 4;
  if (ch <= 'l') return 5;
  if (ch <= 'n') return 6;
  if (ch <= 'p') return 7;
  if (ch <= 's') return 8;
  if (ch <= 'u') return 9;
  return 0;
}

int nextnode(int node, int digit)
/* przejdz do nastepnego wezla po krawedzi z dana literka (stworz wezeli jesli nie istnieje) */
{
  int i;

  assert((node >= 0) && (node < treesize));
  assert((digit >= 0) && (digit < 10));
  if (tree[node].child[digit] < 0)
  {
    /* wezel jeszcze nie istnieje, wiec go tworzymy i inicjalizujemy */
    for (i = 0; i < 10; ++i)
    {
      tree[treesize].child[i] = -1;
    }
    tree[treesize].cnt = 0;
    tree[node].child[digit] = treesize;
    ++treesize;
    return treesize-1;
  }
  assert((tree[node].child[digit] > 0) && (tree[node].child[digit] < treesize));
  return tree[node].child[digit];
}


int decode(int pos, int node)
{
  int sum;
  int newnode;

  if (pos >= L)
  {
    if (node > 0)
    {
      return 0;
    }
    return 1;
  }

  newnode = tree[node].child[number[pos]];
  
  sum = 0;
  if (newnode >= 0)
  {
    if (tree[newnode].cnt > 0)
    {
      --tree[newnode].cnt; /* nie pozwol uzyc tego samego slowa przy dekodowaniu reszty */
      sum += (tree[newnode].cnt+1)*decode(pos+2, 0);
      ++tree[newnode].cnt; /* wracajac, odtworz poprzedni licznik */
    }
    sum += decode(pos+1, newnode);
  }
  
  if (0 == node)
  {
    sum += decode(pos+1, 0);
  }

  return sum;
}


int main()
{
  int d;
  int i, j;
  int scanres;
  char str[11];
  int size;
  int node;
  
  
  /* wczyraj liczbe testow */
  scanres = scanf("%d", &d);
  assert(1 == scanres);
  assert((d > 0) && (d <= MAXD));

  while (d--)
  {
    /* wczytj slowa i zbuduj drzewo */
    scanres = scanf("%d", &M);
    assert(1 == scanres);
    assert((M >= 0) && (M <= MAXM));

    for (j = 0; j < 10; ++j)
    {
      tree[0].child[j] = -1;
    }
    tree[0].cnt = 0;
    treesize = 1;

    for (i = 0; i < M; ++i)
    {
      scanres = scanf("%s", str);
      assert(1 == scanres);
      size = strlen(str);
      assert((size > 0) && (size <= 10));
      if (size > MAXL)
      {
        continue;
      }
      
      node = 0;
      for (j = 0; j < size; ++j)
      {
        node = nextnode(node, char2dig(str[j]));
      }
      ++tree[node].cnt;
    }

    /* wczytaj telefony i przetworz je na biezaco */
    scanres = scanf("%d%d", &N, &L);
    assert(2 == scanres);
    assert((N >= 0) && (N <= MAXN));
    assert((L > 0) && (L <= MAXL));
    for (i = 0; i < N; ++i)
    {
      scanres = scanf("%s", str);
      assert(1 == scanres);
      size = strlen(str);
      assert(L == strlen(str));

      for (j = 0; j < L; ++j)
      {
        number[j] = str[j]-'0';
      }
      printf("%d\n", decode(0, 0));
    }
  }


  return 0;
}

